"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var handler_1 = require("../handler");
var fakecontext_1 = require("./fakecontext");
var fakegithub_1 = require("./fakegithub");
it("performs a label addition from an action config", function () {
    expect.assertions(2);
    var github = new fakegithub_1.FakeGithub([]);
    var context = new fakecontext_1.FakeContext({ sender: { type: "User" }, action: "opened", issue: { labels: [] } }, github, {});
    var config = { issues: { opened: { add: ["triage"] } } };
    return handler_1.handle(context, config).then(function (resp) {
        expect(github.labelsAdded).toEqual(["triage"]);
        expect(github.labelsRemoved).toEqual([]);
    });
});
it("performs multiple label additions from an action config", function () {
    expect.assertions(2);
    var github = new fakegithub_1.FakeGithub([]);
    var context = new fakecontext_1.FakeContext({ sender: { type: "User" }, action: "opened", issue: { labels: [] } }, github, {});
    var config = { issues: { opened: { add: ["triage", "test"] } } };
    return handler_1.handle(context, config).then(function (resp) {
        expect(github.labelsAdded).toEqual(["triage", "test"]);
        expect(github.labelsRemoved).toEqual([]);
    });
});
it("doesn't perform a label addition when the label is already on the issue/PR", function () {
    expect.assertions(2);
    var github = new fakegithub_1.FakeGithub([]);
    var context = new fakecontext_1.FakeContext({ sender: { type: "User" }, action: "opened", issue: { labels: [] } }, github, {});
    var config = { issues: { opened: { add: ["triage"] } } };
    return handler_1.handle(context, config).then(function (resp) {
        expect(github.labelsAdded).toEqual(["triage"]);
        expect(github.labelsRemoved).toEqual([]);
    });
});
it("performs a label removal from an action config", function () {
    expect.assertions(2);
    var github = new fakegithub_1.FakeGithub([]);
    var context = new fakecontext_1.FakeContext({
        sender: { type: "User" },
        action: "opened",
        issue: { labels: [{ name: "triage" }] },
    }, github, {});
    var config = { issues: { opened: { remove: ["triage"] } } };
    return handler_1.handle(context, config).then(function (resp) {
        expect(github.labelsRemoved).toEqual(["triage"]);
        expect(github.labelsAdded).toEqual([]);
    });
});
it("performs multiple label removals from an action config", function () {
    expect.assertions(2);
    var github = new fakegithub_1.FakeGithub([]);
    var context = new fakecontext_1.FakeContext({
        sender: { type: "User" },
        action: "opened",
        issue: { labels: [{ name: "triage" }, { name: "test" }] },
    }, github, {});
    var config = {
        issues: { opened: { remove: ["triage", "test"] } },
    };
    return handler_1.handle(context, config).then(function (resp) {
        expect(github.labelsRemoved).toEqual(["triage", "test"]);
        expect(github.labelsAdded).toEqual([]);
    });
});
it("doesn't perform a label removal when the label isn't present on the issue/PR", function () {
    expect.assertions(2);
    var github = new fakegithub_1.FakeGithub([]);
    var context = new fakecontext_1.FakeContext({ sender: { type: "User" }, action: "opened", issue: { labels: [] } }, github, {});
    var config = { issues: { opened: { remove: ["triage"] } } };
    return handler_1.handle(context, config).then(function (resp) {
        expect(github.labelsRemoved).toEqual([]);
        expect(github.labelsAdded).toEqual([]);
    });
});
//# sourceMappingURL=handler.test.js.map